@@ -1,7 +1,7 @@
 import os 
 import sqlite3 
 
-__version__ = version = '2.1.5'
+__version__ = version = '2.1.6'
 
 SPECIAL_CHARS = r"~!#$%^&*()-=+[]\{}:;,._||" + r'"' + r"'<>?/0123456789"
 INSERT_SPECIAL_CHARS = r"0123456789" + r"-_()[]:/.,@#&" 
@@ -24,10 +24,10 @@ def __selroutine():
     Wordlists = {item[0] : item[1] for item in Wordlists}
  
 def __sroutine1():
-    
-    import subprocess, sys     
-    subprocess.call([sys.executable, '-m' , 'meteor_diceware.utils' , 'create' , 'main' , '-w'])
-    subprocess.call([sys.executable , '-m' , 'meteor_diceware.utils' , 'edit' , 'main' , '-f' , os.path.join(ProgPath , 'actual_diceware.txt')])
+        
+    os.environ.update({'METEOR_DICEWARE_INTERNAL_WORDLIST_CREATION_PROCESS_UNDERWAY' :  '1' })   
+    subprocess.call([sys.executable, '-m' , 'meteor_diceware.utils' , 'create' , 'main' , '-w'] , env = os.environ)
+    subprocess.call([sys.executable , '-m' , 'meteor_diceware.utils' , 'edit' , 'main' , '-f' , os.path.join(ProgPath , 'actual_diceware.txt')] , env = os.environ )
 
 __initdb = lambda : DBCursor.executescript(open(os.path.join(ProgPath , 'init.sql') , 'r' , encoding = 'utf8').read())
 
@@ -44,8 +44,13 @@ try:
 except sqlite3.OperationalError:
     
     __initdb()
-    __sroutine1()
-    __selroutine()
+    
+    if 'METEOR_DICEWARE_INTERNAL_WORDLIST_CREATION_PROCESS_UNDERWAY' in os.environ:
+        Wordlists = {}
+    
+    else:        
+        __sroutine1()
+        __selroutine()
     
 except:
     
